==> ted-2.9.src.tar.gz: Ted-2.9/appUtil/docFont.h <==
/************************************************************************/
/*  Attributes of text.							*/
/************************************************************************/

#   ifndef	DOC_FONT_H
#   define	DOC_FONT_H

typedef struct TextAttribute
    {
    short int		taFontNumber;
    unsigned int	taFontSizeHalfPoints:10;
    unsigned int	taFontIsBold:1;
    unsigned int	taFontIsSlanted:1;
    unsigned int	taIsUnderlined:1;
    unsigned int	taShowAsLink:1;

    unsigned int	taSmallCaps:1;
    unsigned int	taHasStrikeThrough:1;
    unsigned int	taCapitals:1;

    unsigned int	taSuperSub:2;
#   define		DOCfontREGULAR		0
#   define		DOCfontSUPERSCRIPT	1
#   define		DOCfontSUBSCRIPT	2
    } TextAttribute;

#   define	TAupdNONE			(0)

#   define	TAupdFONTFAMILY			(1<<0)
#   define	TAupdFONTSIZE			(1<<1)
#   define	TAupdFONTBOLD			(1<<2)
#   define	TAupdFONTSLANTED		(1<<3)
#   define	TAupdTEXTUNDERLINED		(1<<4)
#   define	TAupdSHOWASLINK			(1<<5)
#   define	TAupdSUPERSUB			(1<<6)
#   define	TAupdSMALLCAPS			(1<<7)
#   define	TAupdCAPITALS			(1<<8)
#   define	TAupdSTRIKETHROUGH		(1<<9)

#   define	TAupdALL			( TAupdFONTFAMILY	|\
						  TAupdFONTSIZE		|\
						  TAupdFONTBOLD		|\
						  TAupdFONTSLANTED	|\
						  TAupdTEXTUNDERLINED	|\
						  TAupdSHOWASLINK	|\
						  TAupdSUPERSUB		|\
						  TAupdSMALLCAPS	|\
						  TAupdCAPITALS		|\
						  TAupdSTRIKETHROUGH	)

#   define	docEqualFontAttributes(ta1,ta2) ( \
		(ta1)->taFontIsBold == (ta2)->taFontIsBold && \
		(ta1)->taFontIsSlanted == (ta2)->taFontIsSlanted )

#   define	docEqualFont(ta1,ta2) ( \
		(ta1)->taFontNumber == (ta2)->taFontNumber && \
		(ta1)->taFontSizeHalfPoints == (ta2)->taFontSizeHalfPoints && \
		(ta1)->taSuperSub == (ta2)->taSuperSub && \
		(ta1)->taSmallCaps == (ta2)->taSmallCaps && \
		docEqualFontAttributes( (ta1), (ta2) ) )

#   define	docEqualTextAttributes(ta1,ta2) ( \
		docEqualFont((ta1),(ta2)) && \
		(ta1)->taIsUnderlined == (ta2)->taIsUnderlined && \
		(ta1)->taHasStrikeThrough == (ta2)->taHasStrikeThrough && \
		(ta1)->taCapitals == (ta2)->taCapitals && \
		(ta1)->taShowAsLink == (ta2)->taShowAsLink )

/************************************************************************/
/*									*/
/*  Font Administration.						*/
/*									*/
/************************************************************************/

#   define	FONTwidthNARROW		0
#   define	FONTwidthCONDENSED	1
#   define	FONTwidthNORMAL		2
#   define	FONTwidthEXTENDED	3

typedef struct DocumentFontInstance
    {
    TextAttribute	dfiAttribute;
    int			dfiPhysicalFont;
    int			dfiPsFaceNumber;
    } DocumentFontInstance;

typedef struct DocumentFont
    {
    char *			dfFamilyStyle;	/*  fnil, fswiss ..	*/
    char *			dfName;		/*  Helvetica,		*/
						/*  Helvetica Narrow.	*/
    int				dfDocFamilyNumber;/*  f0, f1 ...	*/

    int				dfPsFamilyNumber;

    int				dfInstanceCount;
    DocumentFontInstance *	dfInstances;

    int				dfCharset;	/*  fcharsetN		*/

    int				dfPitch;	/*  fprqN		*/
    } DocumentFont;

#   define FONTpitchDEFAULT		0
#   define FONTpitchFIXED		1
#   define FONTpitchVARIABLE		2

#   define FONTcharsetDEFAULT		1
#   define FONTcharsetSYMBOL		2
#   define FONTcharsetOEM		255
#   define FONTcharsetANSI		0		/*  cpg 1252	*/
#   define FONTcharsetRUSSIAN		204		/*  cpg 1251	*/
#   define FONTcharsetEE		238		/*  cpg 1250	*/
#   define FONTcharsetGREEK		161		/*  cpg 1253	*/
#   define FONTcharsetTURKISH		162		/*  cpg 1254	*/
#   define FONTcharsetBALTIC		186		/*  cpg 1257	*/
#   define FONTcharsetHEBREW		177		/*  cpg 1255	*/
#   define FONTcharsetARABIC		178		/*  cpg 1256	*/
#   define FONTcharsetSHIFTJIS		128		/*  cpg 932	*/
#   define FONTcharsetHANGEUL		129		/*  cpg 949	*/
#   define FONTcharsetGB2313		134		/*  cpg 936	*/
#   define FONTcharsetCHINESEBIG5	136		/*  cpg 950	*/

typedef struct DocumentFontList
    {
    int			dflCount;
    DocumentFont *	dflFonts;
    } DocumentFontList;

/************************************************************************/
/*									*/
/*  Font information.							*/
/*									*/
/*  Used to map a users idea of fonts to implementation fonts.		*/
/*  Used by the font chooser to select fonts.				*/
/*									*/
/************************************************************************/
typedef struct AppFontTypeface
    {
    char *			aftFaceName;
    int *			aftSizes;
    int				aftSizeCount;
    unsigned int		aftIsBold:1;
    unsigned int		aftIsSlanted:1;
    unsigned int		aftIsScalable:1;
    unsigned int		aftIsFixedWidth:1;
    void *			aftPrintingData;
    char *			aftXQueryFormat;
    int				aftWidth;
    } AppFontTypeface;

typedef struct AppFontFamily
    {
    char *		affFontFamilyName;
    char *		affFontFamilyText;
    AppFontTypeface *	affFaces;
    int			affFaceCount;
    unsigned int	affHasFixedWidth:1;
    unsigned int	affHasProportionalWidth:1;
    unsigned int	affWidth;
					/********************************/
    unsigned int	affEncoding;	/*  Different meaning for	*/
					/*  PostScript and X11		*/
					/********************************/
    } AppFontFamily;

/************************************************************************/
/*									*/
/*  Default attributes.							*/
/*									*/
/************************************************************************/
extern TextAttribute   DocDefaultAttributes;

/************************************************************************/
/*  Routine declarations.						*/
/************************************************************************/

extern void docInitFontFamily(	AppFontFamily *	aff );

extern void docInitFont(	DocumentFont *	df );

extern void docCleanFont(	DocumentFont *	df );

extern int docCopyFont(	DocumentFont *		to,
			const DocumentFont *	from );

extern void docInitFontList(	DocumentFontList *	dfl );

extern void docCleanFontList(	DocumentFontList *	dfl );

extern int docCopyFontList(	DocumentFontList *		to,
				const DocumentFontList *	from );

extern const char *	docFontFamilyStyle( const char * fontFamilyName );

extern DocumentFont *	docInsertFont(	DocumentFontList *	dfl,
					int			n,
					const char *		familyStyle,
					const char *		fontName );

extern void docInitTextAttribute(	TextAttribute *	ta	);

extern unsigned int docAttributeDifference(	TextAttribute		ta1,
						TextAttribute		ta2,
						unsigned int		m );

extern void docUpdateTextAttribute(	unsigned int *		pChangeMask,
					unsigned int		updMask,
					TextAttribute *		taTo,
					TextAttribute		taFrom );

extern int docFontCompareFaces(	const void *	veft1,
				const void *	veft2 );

extern int docGetFontByName(	DocumentFontList *	dfl,
				const char *		fontFamilyName );

#   endif	/*  DOC_FONT_H	*/

==> ted-2.10.src.tar.gz: Ted-2.10/appUtil/docFont.h <==
/************************************************************************/
/*  Attributes of text.							*/
/************************************************************************/

#   ifndef	DOC_FONT_H
#   define	DOC_FONT_H

typedef struct TextAttribute
    {
    short int		taFontNumber;
    unsigned int	taFontSizeHalfPoints:10;
    unsigned int	taFontIsBold:1;
    unsigned int	taFontIsSlanted:1;
    unsigned int	taIsUnderlined:1;
    unsigned int	taShowAsLink:1;

    unsigned int	taSmallCaps:1;
    unsigned int	taHasStrikeThrough:1;
    unsigned int	taCapitals:1;

    unsigned int	taSuperSub:2;
#   define		DOCfontREGULAR		0
#   define		DOCfontSUPERSCRIPT	1
#   define		DOCfontSUBSCRIPT	2
    } TextAttribute;

typedef enum TextProperty
    {
    TAprop_NONE= -1,

    TApropFONTFAMILY= 0,
    TApropFONTSIZE,
    TApropFONTBOLD,
    TApropFONTSLANTED,
    TApropTEXTUNDERLINED,
    TApropSHOWASLINK,
    TApropSUPERSUB,
    TApropSMALLCAPS,
    TApropCAPITALS,
    TApropSTRIKETHROUGH,

    TAprop_COUNT
    } TextProperty;

#   define	TAupd_NONE		(0)

#   define	TAupdALL		((1<<TApropFONTFAMILY)		|\
					 (1<<TApropFONTSIZE)		|\
					 (1<<TApropFONTBOLD)		|\
					 (1<<TApropFONTSLANTED)		|\
					 (1<<TApropTEXTUNDERLINED)	|\
					 (1<<TApropSHOWASLINK)		|\
					 (1<<TApropSUPERSUB)		|\
					 (1<<TApropSMALLCAPS)		|\
					 (1<<TApropCAPITALS)		|\
					 (1<<TApropSTRIKETHROUGH)	)

#   define	docEqualFontAttributes(ta1,ta2) ( \
		(ta1)->taFontIsBold == (ta2)->taFontIsBold && \
		(ta1)->taFontIsSlanted == (ta2)->taFontIsSlanted )

#   define	docEqualFont(ta1,ta2) ( \
		(ta1)->taFontNumber == (ta2)->taFontNumber && \
		(ta1)->taFontSizeHalfPoints == (ta2)->taFontSizeHalfPoints && \
		(ta1)->taSuperSub == (ta2)->taSuperSub && \
		(ta1)->taSmallCaps == (ta2)->taSmallCaps && \
		docEqualFontAttributes( (ta1), (ta2) ) )

#   define	docEqualTextAttributes(ta1,ta2) ( \
		docEqualFont((ta1),(ta2)) && \
		(ta1)->taIsUnderlined == (ta2)->taIsUnderlined && \
		(ta1)->taHasStrikeThrough == (ta2)->taHasStrikeThrough && \
		(ta1)->taCapitals == (ta2)->taCapitals && \
		(ta1)->taShowAsLink == (ta2)->taShowAsLink )

/************************************************************************/
/*									*/
/*  Font Administration.						*/
/*									*/
/************************************************************************/

#   define	FONTwidthNARROW		0
#   define	FONTwidthCONDENSED	1
#   define	FONTwidthNORMAL		2
#   define	FONTwidthEXTENDED	3

typedef struct DocumentFontInstance
    {
    TextAttribute	dfiAttribute;
    int			dfiPhysicalFont;
    int			dfiPsFaceNumber;
    } DocumentFontInstance;

typedef struct DocumentFont
    {
    char *			dfFamilyStyle;	/*  fnil, fswiss ..	*/
    char *			dfName;		/*  Helvetica,		*/
						/*  Helvetica Narrow.	*/
    int				dfDocFamilyNumber;/*  f0, f1 ...	*/

    int				dfPsFamilyNumber;

    int				dfInstanceCount;
    DocumentFontInstance *	dfInstances;

    int				dfCharset;	/*  fcharsetN		*/

    int				dfPitch;	/*  fprqN		*/
    } DocumentFont;

#   define FONTpitchDEFAULT		0
#   define FONTpitchFIXED		1
#   define FONTpitchVARIABLE		2

#   define FONTcharsetDEFAULT		1
#   define FONTcharsetSYMBOL		2
#   define FONTcharsetOEM		255
#   define FONTcharsetANSI		0		/*  cpg 1252	*/
#   define FONTcharsetRUSSIAN		204		/*  cpg 1251	*/
#   define FONTcharsetEE		238		/*  cpg 1250	*/
#   define FONTcharsetGREEK		161		/*  cpg 1253	*/
#   define FONTcharsetTURKISH		162		/*  cpg 1254	*/
#   define FONTcharsetBALTIC		186		/*  cpg 1257	*/
#   define FONTcharsetHEBREW		177		/*  cpg 1255	*/
#   define FONTcharsetARABIC		178		/*  cpg 1256	*/
#   define FONTcharsetSHIFTJIS		128		/*  cpg 932	*/
#   define FONTcharsetHANGEUL		129		/*  cpg 949	*/
#   define FONTcharsetGB2313		134		/*  cpg 936	*/
#   define FONTcharsetCHINESEBIG5	136		/*  cpg 950	*/

typedef struct DocumentFontList
    {
    int			dflCount;
    DocumentFont *	dflFonts;
    } DocumentFontList;

/************************************************************************/
/*									*/
/*  Font information.							*/
/*									*/
/*  Used to map a users idea of fonts to implementation fonts.		*/
/*  Used by the font chooser to select fonts.				*/
/*									*/
/************************************************************************/

typedef struct AppFontTypeface
    {
    char *			aftFaceName;
    int *			aftSizes;
    int				aftSizeCount;
    unsigned int		aftIsBold:1;
    unsigned int		aftIsSlanted:1;
    unsigned int		aftIsScalable:1;
    unsigned int		aftIsFixedWidth:1;
    void *			aftPrintingData;
    char *			aftXQueryFormat;
    int				aftWidth;
    } AppFontTypeface;

typedef struct AppFontFamily
    {
    char *		affFontFamilyName;
    char *		affFontFamilyText;
    AppFontTypeface *	affFaces;
    int			affFaceCount;
    unsigned int	affHasFixedWidth:1;
    unsigned int	affHasProportionalWidth:1;
    unsigned int	affWidth;
					/********************************/
    unsigned int	affEncoding;	/*  Different meaning for	*/
					/*  PostScript and X11		*/
					/********************************/
    } AppFontFamily;

/************************************************************************/
/*									*/
/*  Default attributes.							*/
/*									*/
/************************************************************************/
extern TextAttribute   DocDefaultAttributes;

/************************************************************************/
/*  Routine declarations.						*/
/************************************************************************/

extern void docInitFontFamily(	AppFontFamily *	aff );

extern void docInitFont(	DocumentFont *	df );

extern void docCleanFont(	DocumentFont *	df );

extern int docCopyFont(	DocumentFont *		to,
			const DocumentFont *	from );

extern void docInitFontList(	DocumentFontList *	dfl );

extern void docCleanFontList(	DocumentFontList *	dfl );

extern int docCopyFontList(	DocumentFontList *		to,
				const DocumentFontList *	from );

extern const char *	docFontFamilyStyle( const char * fontFamilyName );

extern DocumentFont *	docInsertFont(	DocumentFontList *	dfl,
					int			n,
					const char *		familyStyle,
					const char *		fontName );

extern void docInitTextAttribute(	TextAttribute *	ta	);

extern unsigned int docAttributeDifference(	TextAttribute		ta1,
						TextAttribute		ta2,
						unsigned int		m );

extern void docUpdateTextAttribute(	unsigned int *		pChangeMask,
					unsigned int		updMask,
					TextAttribute *		taTo,
					TextAttribute		taFrom );

extern int docFontCompareFaces(	const void *	veft1,
				const void *	veft2 );

extern int docGetFontByName(	DocumentFontList *	dfl,
				const char *		fontFamilyName );

#   endif	/*  DOC_FONT_H	*/
